@@ -9,8 +9,8 @@
 
 ;; Maintainer: Campbell Barton <ideasman42@gmail.com>
 ;; Keywords: convenience
-;; Package-Version: 20251126.529
-;; Package-Revision: 7efdeecb1eff
+;; Package-Version: 20260106.250
+;; Package-Revision: e5357f318eae
 ;; URL: https://codeberg.org/ideasman42/emacs-repeat-fu
 ;; Package-Requires: ((emacs "29.1"))
 
@@ -57,7 +57,7 @@ By convention, the following rules are followed for bundled presets.
 
 - Any selection that uses the mouse cursor causes selection
   commands to be ignored as they can't be repeated reliably.
-- Undo/redo commands wont be handled as a new edit to be repeated.
+- Undo/redo commands won't be handled as a new edit to be repeated.
   This means it's possible to undo the `repeat-fu-execute' and repeat the
   action at a different location instead of repeating the undo."
   :type 'symbol)
@@ -68,7 +68,7 @@ By convention, the following rules are followed for bundled presets.
 
 (defcustom repeat-fu-last-used-on-quit t
   "When the last command is `keyboard-quit', repeat the last used macro.
-This allows any edit, to be ignored so the last repeated action can be reused.
+This allows any edit to be ignored so the last repeated action can be reused.
 
 This can be useful if an edit is made by accident."
   :type 'boolean)
@@ -76,15 +76,15 @@ This can be useful if an edit is made by accident."
 (defcustom repeat-fu-buffer-size 512
   "Maximum number of steps to store.
 When nil, all commands are stored,
-the `repeat-fu-backend' is responsible for ensuring buffer doesn't expand indefinitely."
-  :type 'integer)
+the `repeat-fu-backend' is responsible for ensuring the buffer doesn't expand indefinitely."
+  :type '(choice natnum (const nil)))
 
 
 ;; ---------------------------------------------------------------------------
 ;; Public Variables
 
 (defvar repeat-fu-backend nil
-  "A P-list of callbacks used to implement repeat logic:
+  "A plist of callbacks used to implement repeat logic:
 
 :macros-extract
   Extract a macro from the history.
@@ -104,7 +104,7 @@ the `repeat-fu-backend' is responsible for ensuring buffer doesn't expand indefi
   and returns the macro which should be used.
 
 :pre-data (optional)
-  Store data before the command .
+  Store data before the command.
 
 :post-data
   Store data after the command.
@@ -146,7 +146,7 @@ The :post-data callback in `repeat-fu-backend' may use it.")
 ;; ==============
 
 ;; Needed for commands that override this-command.
-;; This data stored by `repeat-fu--pre-fn' on entering each command.
+;; This data is stored by `repeat-fu--pre-fn' on entering each command.
 (defvar repeat-fu--pre-data nil)
 
 ;; Did last command change buffer?
@@ -158,7 +158,7 @@ The :post-data callback in `repeat-fu-backend' may use it.")
 ;; Use an accumulating buffer OR a ring buffer.
 
 ;; Needed so `repeat-fu-execute' can skip itself.
-;; Executing the macro overwrites `this-command.'.
+;; Executing the macro overwrites `this-command'.
 ;; When set, the command is not stored.
 (defvar repeat-fu--cmd-skip nil)
 
@@ -275,10 +275,8 @@ The :post-data callback in `repeat-fu-backend' may use it.")
   (condition-case err
       (funcall repeat-fu--macros-extract-fn cmd-buffer)
     (error
-     (progn
-       (message "Repeat-FU: error in `repeat-fu--macros-extract-fn' (%s)"
-                (error-message-string err))
-       nil))))
+     (message "Repeat-FU: error in `repeat-fu--macros-extract-fn' (%s)" (error-message-string err))
+     nil)))
 
 (defsubst repeat-fu--select-fn-wrapper (kbuf-list)
   "Select the macro from KBUF-LIST."
@@ -286,9 +284,8 @@ The :post-data callback in `repeat-fu-backend' may use it.")
   (condition-case err
       (funcall repeat-fu--macros-select-fn kbuf-list)
     (error
-     (progn
-       (message "Repeat-FU: error in `repeat-fu--post-fn' (%s)" (error-message-string err))
-       nil))))
+     (message "Repeat-FU: error in `repeat-fu--macros-select-fn' (%s)" (error-message-string err))
+     nil)))
 
 (defsubst repeat-fu--pre-fn-wrapper ()
   "Pre command wrapper."
@@ -318,9 +315,8 @@ The :post-data callback in `repeat-fu-backend' may use it.")
   "Extract a macro from previous commands or return the last extracted macro."
   (declare (important-return-value t))
 
-  (when repeat-fu-last-used-on-quit
-    (when (eq last-command 'keyboard-quit)
-      (repeat-fu--clear)))
+  (when (and repeat-fu-last-used-on-quit (eq last-command 'keyboard-quit))
+    (repeat-fu--clear))
 
   (let ((kbuf-list (repeat-fu--extract-fn-wrapper (repeat-fu--cmd-buffer-get))))
     (when kbuf-list
@@ -377,7 +373,7 @@ The :post-data callback in `repeat-fu-backend' may use it.")
   (remove-hook 'prefix-command-preserve-state-hook #'repeat-fu--prefix-command-hook t))
 
 (defun repeat-fu--hooks-add ()
-  "Setup hooks."
+  "Set up hooks."
   (declare (important-return-value nil))
 
   (add-hook 'pre-command-hook #'repeat-fu--pre-hook nil t)
@@ -415,12 +411,11 @@ The :post-data callback in `repeat-fu-backend' may use it.")
         (:pre-data (setq pre-fn (pop preset)))
         (:post-data (setq post-fn (pop preset)))
         (_
-         (progn
-           (setq preset (cdr-safe preset))
-           (message "unknown keyword: %S" key)))))
+         (setq preset (cdr-safe preset))
+         (message "Unknown keyword: %S" key))))
 
     (when preset
-      (message "presets contain non key/value pairs: %S " preset)
+      (message "Presets contain non key/value pairs: %S" preset)
       (setq success nil))
 
     (unless macros-extract-fn
@@ -429,10 +424,14 @@ The :post-data callback in `repeat-fu-backend' may use it.")
     (unless macros-select-fn
       (message "Error, the key :macros-select was missing!")
       (setq success nil))
-    (unless pre-fn
-      (message "Error, the key :post-data was missing")
+    (unless post-fn
+      (message "Error, the key :post-data was missing!")
       (setq success nil))
 
+    ;; Use `ignore' as the default for the optional :pre-data callback.
+    (unless pre-fn
+      (setq pre-fn #'ignore))
+
     (setq repeat-fu--pre-fn pre-fn)
     (setq repeat-fu--post-fn post-fn)
     (setq repeat-fu--macros-extract-fn macros-extract-fn)
@@ -479,18 +478,16 @@ The :post-data callback in `repeat-fu-backend' may use it.")
 
 (defun repeat-fu--commands-mark-skip (commands value)
   "Ignore COMMANDS entirely.
-Commands that aren't related to editing should be marked especially save.
+Commands that aren't related to editing should be marked as safe.
 The property is set to VALUE which should typically be true."
   (declare (important-return-value nil))
   (repeat-fu--commands-mark commands value 'repeat-fu-skip))
 
 (defun repeat-fu--commands-mark-skip-active (commands value)
   "Ignore COMMANDS from region activation.
-This means, any commands that create the region using these commands
+This means any commands that create the region using these commands
 won't repeat any active-region manipulation.
-This should typically be used any region manipulation that uses the mouse.
-
-Commands such as save & undo should be included.
+This should typically be used for region manipulation that uses the mouse.
 The property is set to VALUE which should typically be true."
   (declare (important-return-value nil))
   (repeat-fu--commands-mark commands value 'repeat-fu-skip-active))
@@ -554,7 +551,7 @@ The PLIST must only contain the following keys.
    When non-nil, the command won't include the active-region
    when one of these functions was used to create it.
 
-   By default, ``mouse-set-region`` uses this so repeating an action
+   By default, `mouse-set-region' uses this so repeating an action
    doesn't attempt to replay the mouse-drag used for selection.
 :skip-change
    When non-nil, commands that change the buffer will be skipped
@@ -604,9 +601,6 @@ The prefix argument ARG serves as a repeat count."
   (interactive "p")
   (repeat-fu--mode-enabled-or-error)
 
-  (unless arg
-    (setq arg 1))
-
   ;; Execution must not trigger infinite recursion,
   ;; nor record any new steps.
   (setq repeat-fu--cmd-skip t)
@@ -614,7 +608,7 @@ The prefix argument ARG serves as a repeat count."
   (let ((kbuf (repeat-fu--extract-repeat-macro-or-last)))
     (cond
      ((null kbuf)
-      (message "Nothing to repeat"))
+      (message "Nothing to repeat."))
      (t
       ;; Execute the macro.
       (repeat-fu--without-hooks
@@ -624,14 +618,14 @@ The prefix argument ARG serves as a repeat count."
           ((error quit exit)
            (repeat-fu--clear)
            (setq repeat-fu--macros-last nil)
-           (message "Repeat reset (failed)"))))))))
+           (message "Repeat reset (failed)."))))))))
 
 ;;;###autoload
 (defun repeat-fu-copy-to-last-kbd-macro ()
   "Copy the current `repeat-fu' command buffer to the `last-kbd-macro' variable.
 Then it can be called with `call-last-kbd-macro', named with
-`name-last-kbd-macro', or even saved for later use with
-`name-last-kbd-macro'"
+`name-last-kbd-macro', or saved for later use with
+`insert-kbd-macro'."
   (declare (important-return-value nil))
   (interactive)
   (repeat-fu--mode-enabled-or-error)
@@ -663,7 +657,8 @@ Then it can be called with `call-last-kbd-macro', named with
           'repeat-fu--macros-last
           'repeat-fu--macros-select-fn
           'repeat-fu--post-fn
-          'repeat-fu--pre-data)))
+          'repeat-fu--pre-data
+          'repeat-fu--pre-fn)))
 
     (cond
      ((not repeat-fu-mode)
@@ -675,18 +670,18 @@ Then it can be called with `call-last-kbd-macro', named with
         (set var (default-value var))))
      (t
       (unless repeat-fu-backend
-        (let ((preset-value (symbol-name repeat-fu-preset)))
-          (let ((preset-sym (intern (concat "repeat-fu-preset-" preset-value))))
-            (when (condition-case err
-                      (progn
-                        (require preset-sym)
-                        t)
-                    (error
-                     (message "repeat-fu: preset '%s' not found! (%s)"
-                              preset-value
-                              (error-message-string err))
-                     nil))
-              (setq repeat-fu-backend (funcall preset-sym))))))
+        (let* ((preset-value (symbol-name repeat-fu-preset))
+               (preset-sym (intern (concat "repeat-fu-preset-" preset-value))))
+          (when (condition-case err
+                    (progn
+                      (require preset-sym)
+                      t)
+                  (error
+                   (message "repeat-fu: preset '%s' not found! (%s)"
+                            preset-value
+                            (error-message-string err))
+                   nil))
+            (setq repeat-fu-backend (funcall preset-sym)))))
 
       (repeat-fu--preset-refresh)
 
